@@ -1,34 +1,20 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 2 of the License, or 
  *   (at your option) any later version.
- *
+ * 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software
+ *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:		log_read.c
- *
- *   COMPONENT_NAME: 	jfslib
- *
- *   FUNCTIONS:
- *              findEndOfLog()
- *              pageVal
- *              getLogpage
- *              setLogpage
- *              logRead
- *              moveWords()
- *
  */
-
 #include "jfs_types.h"
 #include <time.h>
 #include <stdio.h>
@@ -119,27 +105,24 @@ extern struct vopen vopen[];	/* (88) */
 
 int nextrep;			/* next log buffer pool slot to replace */
 int logptr[4];			/* log pages currently held in logp */
-logpage_t logp[4];		/* log page buffer pool  */
+struct logpage logp[4];		/* log page buffer pool  */
 
 /*
  * external references
  */
 extern int errno;
 extern int logError(int, int);
-extern int32_t alloc_storage(int32_t, void **, int32_t *);
-
 extern void fsck_send_msg(int, int);	/* defined in fsckmsg.c */
 
 /*
  * forward references
  */
-int32_t findEndOfLog(void);
+int findEndOfLog(void);
 int pageVal(int, int *, int *);
-int32_t getLogpage(int);
+int getLogpage(int);
 int setLogpage(int32_t pno, int32_t *, int32_t *, int32_t);
 int logRead(int32_t, struct lrd *, char *);
-int32_t moveWords(int32_t, int32_t *, int32_t *, int32_t *);
-
+int moveWords(int32_t, int32_t *, int32_t *, int32_t *);
 
 /*
  * NAME:        findEndOfLog()
@@ -160,10 +143,11 @@ int32_t moveWords(int32_t, int32_t *, int32_t *, int32_t *);
  *              REFORMAT_ERROR(-3)      - i/o error, reformat the log
  *              MAJOR_ERROR(-2) - other major errors other than EIO.
  */
-int32_t findEndOfLog()
+int findEndOfLog()
 {
 
-	int32_t left, right, pmax, pval, eormax, eorval, k, rc;
+	int rc;
+	int32_t left, right, pmax, pval, eormax, eorval, k;
 
 	/* binary search for logend */
 	left = 2;		/* first page containing log records
@@ -241,7 +225,6 @@ int32_t findEndOfLog()
 	}
 }
 
-
 /*
  * NAME:        pageVal(pno, eor, pmax)
  *
@@ -273,7 +256,6 @@ int pageVal(int pno,		/* page number in log           */
 	return (setLogpage(pno, eor, pmax, buf0));
 }
 
-
 /*
  * NAME:        getLogpage(pno)
  *
@@ -286,9 +268,9 @@ int pageVal(int pno,		/* page number in log           */
  *              REFORMAT_ERROR(-3)      - I/O error, reformat the log
  *              MAJOR_ERROR(-2)         - other major errors other than EIO.
  */
-int32_t getLogpage(int pno)
+int getLogpage(int pno)
 {				/* page of log */
-	int32_t k, rc;
+	int k, rc;
 
 	/*
 	 * is it in buffer pool ?
@@ -305,13 +287,11 @@ int32_t getLogpage(int pno)
 	if (log.location & INLINELOG)
 		rc = ujfs_rw_diskblocks(log.fd,
 					(uint64_t) (log.xaddr + LOGPNTOB(pno)),
-					(unsigned) LOGPSIZE,
-					(char *) &logp[nextrep], GET);
+					(unsigned) LOGPSIZE, (char *) &logp[nextrep], GET);
 	else
 		rc = ujfs_rw_diskblocks(log.fd,
 					(uint64_t) LOGPNTOB(pno),
-					(unsigned) LOGPSIZE,
-					(char *) &logp[nextrep], GET);
+					(unsigned) LOGPSIZE, (char *) &logp[nextrep], GET);
 
 	if (rc != 0) {
 		return (JLOG_READERROR1);
@@ -321,7 +301,6 @@ int32_t getLogpage(int pno)
 	return (nextrep);
 }
 
-
 /*
  * NAME:        setLogpage(pno, eor, pmax, buf)
  *
@@ -360,15 +339,15 @@ int32_t getLogpage(int pno)
  *              MAJOR_ERROR(-2)         - other major error
  */
 int setLogpage(int32_t pno,	/* page number of log           */
-	       int32_t * eor,	/* log header eor to return     */
-	       int32_t * pmax,	/* log header page number to return */
+	       int32_t *eor,	/* log header eor to return     */
+	       int32_t *pmax,	/* log header page number to return */
 	       int32_t buf)
 {				/* logp[] index number for page */
-	int32_t diff1, diff2, rc;
+	int rc;
+	int32_t diff1, diff2;
 
 	/* check that header and trailer are the same */
-	if ((diff1 = (__le32_to_cpu(logp[buf].h.page) -
-		      __le32_to_cpu(logp[buf].t.page))) != 0) {
+	if ((diff1 = (__le32_to_cpu(logp[buf].h.page) - __le32_to_cpu(logp[buf].t.page))) != 0) {
 		if (diff1 > 0)
 			/* Both little-endian */
 			logp[buf].h.page = logp[buf].t.page;
@@ -376,13 +355,11 @@ int setLogpage(int32_t pno,	/* page number of log           */
 			/* Both little-endian */
 			logp[buf].t.page = logp[buf].h.page;
 
-		logp[buf].h.eor = logp[buf].t.eor =
-		    __cpu_to_le16(LOGPHDRSIZE);
+		logp[buf].h.eor = logp[buf].t.eor = __cpu_to_le16(LOGPHDRSIZE);
 		/* empty page */
 	}
 
-	if ((diff2 = (__le16_to_cpu(logp[buf].h.eor) -
-		      __le16_to_cpu(logp[buf].t.eor))) != 0) {
+	if ((diff2 = (__le16_to_cpu(logp[buf].h.eor) - __le16_to_cpu(logp[buf].t.eor))) != 0) {
 		if (diff2 > 0)
 			/* Both little-endian */
 			logp[buf].h.eor = logp[buf].t.eor;
@@ -395,8 +372,7 @@ int setLogpage(int32_t pno,	/* page number of log           */
 	if (diff1 || diff2) {
 		rc = ujfs_rw_diskblocks(log.fd,
 					(uint64_t) (log.xaddr + LOGPNTOB(pno)),
-					(unsigned long) LOGPSIZE,
-					(char *) &logp[buf], PUT);
+					(unsigned long) LOGPSIZE, (char *) &logp[buf], PUT);
 		if (rc != 0) {
 			sprintf(message_parm_0, "(d) %d", pno);
 			msgprms[0] = message_parm_0;
@@ -436,7 +412,7 @@ int setLogpage(int32_t pno,	/* page number of log           */
     *
     * RETURNS:     < 0     - there is an i/o error in reading
     *              > 0     - the address of the end of the preceding log record
-    */
+  */
 int logRead(int32_t logaddr,	/* address of log record to read */
 	    struct lrd *ld,	/* pointer to a log record descriptor */
 	    char *dataptr)
@@ -482,7 +458,7 @@ int logRead(int32_t logaddr,	/* address of log record to read */
 		fsck_send_msg(lrdo_LRMWFAIL1, 1);
 		return (rc);
 	}
-	ujfs_swap_lrd_t(ld);
+	ujfs_swap_lrd(ld);
 
 	/* read the data if there is any */
 	if (ld->length > 0) {
@@ -511,7 +487,6 @@ int logRead(int32_t logaddr,	/* address of log record to read */
 	return (LOGPNTOB(logptr[buf]) + off);
 }
 
-
 /*
  * NAME:        moveWords()
  *
@@ -537,11 +512,11 @@ int logRead(int32_t logaddr,	/* address of log record to read */
  * RETURNS:     = 0             - ok
  *              < 0             - error returned from getLogpage
  */
-int32_t moveWords(int32_t nwords,	/* number of 4-byte words to move */
-		  int32_t * target,	/* address of target (begin address) */
-		  int32_t * buf,	/* index in buffer pool of curr page */
-		  int32_t * offset) 	/* initial offset in buffer pool page */
-{
+int moveWords(int32_t nwords,	/* number of 4-byte words to move */
+		  int32_t *target,	/* address of target (begin address) */
+		  int32_t *buf,		/* index in buffer pool of curr page */
+		  int32_t *offset)
+{				/* initial offset in buffer pool page */
 	int n, j, words, pno;
 	int *ptr;
 
