@@ -1,46 +1,20 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 2 of the License, or
+ *   the Free Software Foundation; either version 2 of the License, or 
  *   (at your option) any later version.
- *
+ * 
  *   This program is distributed in the hope that it will be useful,
  *   but WITHOUT ANY WARRANTY;  without even the implied warranty of
  *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
  *   the GNU General Public License for more details.
  *
  *   You should have received a copy of the GNU General Public License
- *   along with this program;  if not, write to the Free Software
+ *   along with this program;  if not, write to the Free Software 
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
- *
- *   MODULE_NAME:		logredo.c
- *
- *   COMPONENT_NAME: 	jfslib
- *
- *   FUNCTIONS:  jfs_logredo.c: recovery manager
- *
- *              logRedo()  -- The main routine
- *              doMount
- *              openVol
- *              updateSuper
- *              rdwrSuper
- *              bflush
- *              logOpen
- *              lockLog
- *              unlockLog
- *              makeOpen
- *              makeDevice
- *              fsError
- *              logError
- *              recoverExtendFS
- *              alloc_dmap_bitrec
- *              alloc_storage
- *              nfsisloaded
- *
-*/
-
+ */
 #include "jfs_types.h"
 #include <time.h>
 #include <stdio.h>
@@ -135,7 +109,7 @@ int32_t bmap_stg_bytes = 0;
  *    S T U F F    F O R    T H E    L O G
  *
  */
-logsuper_t logsup;		/* log super block */
+struct logsuper logsup;		/* log super block */
 int32_t numdoblk;		/* number of do blocks used     */
 int32_t numnodofile;		/* number of nodo file blocks used  */
 int32_t numExtDtPg = 0;		/* number of extended dtpage blocks used  */
@@ -157,7 +131,7 @@ struct {
 	uuid_t uuid;
 	int fd;
 } primary_vol;
-int LogOpenMode = O_RDWR;	/* logdump sets this to O_RDONLY */
+extern int LogOpenMode;		/* logdump sets this to O_RDONLY */
 
 /*
  * if this flag is set then the primary superblock is
@@ -218,9 +192,9 @@ extern int optind;
 extern int errno;
 extern int initMaps(int32_t);
 extern int updateMaps(int);
-extern int32_t findEndOfLog(void);
+extern int findEndOfLog(void);
 extern int logRead(int32_t, struct lrd *, char *);
-extern int32_t logredoInit(void);
+extern int logredoInit(void);
 extern int doCommit(struct lrd *);
 extern int doExtDtPg(void);
 extern int doNoRedoFile(struct lrd *, uint32_t);
@@ -232,22 +206,22 @@ extern int doUpdateMap(struct lrd *);
 extern void fsck_send_msg(int, int);
 extern int alloc_wrksp(uint32_t, int, int, void **);
 
-extern int open_by_label(uuid_t, int, int);
+extern int open_by_label(uuid_t, int, int, char *);
 extern char log_device[];
 /*
  * forward references
  */
 int doMount(struct lrd *);
-int32_t openVol(int32_t);
-int32_t updateSuper(int vol);
-int32_t rdwrSuper(int32_t, struct superblock *, int32_t);
+int openVol(int32_t);
+int updateSuper(int vol);
+int rdwrSuper(int32_t, struct superblock *, int32_t);
 int bflush(int32_t, struct bufpool *);
-int32_t logOpen(void);
+int logOpen(void);
 int fsError(int, int, int64_t);
 int logError(int, int);
-static int32_t recoverExtendFS(int32_t fd);
-int32_t alloc_storage(int32_t, void **, int32_t *);
-int32_t alloc_dmap_bitrec(dmap_bitmaps_t **);
+static int recoverExtendFS(int32_t fd);
+int alloc_storage(int32_t, void **, int32_t *);
+int alloc_dmap_bitrec(struct dmap_bitmaps **);
 
 /*
  * debug control
@@ -264,7 +238,6 @@ int prtdesc(struct lrd *);
 int32_t dflag = 0;
 #endif
 
-
 /*
  * NAME:        jfs_logredo()
  *
@@ -302,8 +275,8 @@ int32_t dflag = 0;
  * So at logredo time, the xtree for imap is always readable and correct.
  * This is the basic requirement from logredo.
  *
- * the inode map control page (dinomap_t) is only flushed to disk at
- * the umount time. For iag_t, pmap will go to disk at commit time.
+ * the inode map control page (struct dinomap) is only flushed to disk at
+ * the umount time. For iag, pmap will go to disk at commit time.
  * iagnum will not change in run-time.
  * agstart field will stable without extendfs utility. It is TBD for
  * how to handle agstart when extendfs utility is available.
@@ -344,14 +317,14 @@ int32_t dflag = 0;
  *                        That is usually the case. So we can also say
  *                        an aggregate/lv. "-s" is often used for test.
  *
- *  2) dbmap_t.dn_mapsize: This field also indicates aggregate/lv size.
+ *  2) dbmap.dn_mapsize: This field also indicates aggregate/lv size.
  *                        It tells number of aggre. blocks in the
  *                        aggregate/lv. Without extendfs, this field should
  *                        be equivalent to superblock.s_size.
  *                        With extendfs, this field may not be updated
  *                        before a system crash happens. So logredo
  *                        need to update it.
- *  3) dinode_t.di_size:  For an inode of bmap file, this field indicates
+ *  3) dinode.di_size:  For an inode of bmap file, this field indicates
  *                        the logical size of the file. I.e. it contains
  *                        the offset value of the last byte written
  *                        in the file plus one.
@@ -374,7 +347,7 @@ int32_t dflag = 0;
  *                        page into the bmap file for preparing extendfs.
  *                        This hidden dmap page cannot be figured out from
  *                        superblock.s_size, but di_size includes it. Any
- *                        dmapctl_t pages caused by this hidden dmap page
+ *                        dmapctl pages caused by this hidden dmap page
  *                        are also included in di_size.
  *
  * The bmap control page, dmap control pages and dmap pages are all
@@ -531,8 +504,6 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	int highest_lr_byte = 0;
 	int log_has_wrapped = 0;
 	int logend;
-	struct stat buf;
-	int id;
 
 	/*
 	 * store away the indicator of which aggregate superblock
@@ -544,8 +515,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 * loop until we get enough memory to read vmount struct
 	 */
 	mntinfo = (char *) &bufsize;
-	bufsize = sizeof(int);
-
+	bufsize = sizeof (int);
 
 	/*
 	 * validate that the log is not currently in use;
@@ -557,8 +527,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	}
 
 	/* recover from extendfs() ? */
-	if (log.location & INLINELOG &&
-	    (vopen[0].status & FM_EXTENDFS)) {
+	if (log.location & INLINELOG && (vopen[0].status & FM_EXTENDFS)) {
 		fsck_send_msg(lrdo_REXTNDBEGIN, 0);
 		rc = recoverExtendFS(fd);
 		fsck_send_msg(lrdo_REXTNDDONE, 0);
@@ -573,14 +542,13 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	rc = ujfs_rw_diskblocks(log.fd,
 				(uint64_t) (log.xaddr +
 					    LOGPNTOB(LOGSUPER_B)),
-				(unsigned) sizeof(logsuper_t),
-				(char *) &logsup, GET);
+				(unsigned) sizeof (struct logsuper), (char *) &logsup, GET);
 	if (rc != 0) {
 		fsck_send_msg(lrdo_CANTREADLOGSUP, 0);
 		rc = LOGSUPER_READ_ERROR;
 		goto error_out;
 	}
-	ujfs_swap_logsuper_t(&logsup);
+	ujfs_swap_logsuper(&logsup);
 
 	if (logsup.magic != LOGMAGIC) {
 		fsck_send_msg(lrdo_LOGSUPBADMGC, 0);
@@ -629,11 +597,10 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 
 		fsck_send_msg(lrdo_LOGENDBAD1, 0);
 		logError(LOGEND, 0);
-		ujfs_swap_logsuper_t(&logsup);
+		ujfs_swap_logsuper(&logsup);
 		rc = ujfs_rw_diskblocks(log.fd,
 					(log.xaddr + LOGPNTOB(LOGSUPER_B)),
-					(unsigned long) LOGPSIZE,
-					(char *) &logsup, PUT);
+					(unsigned long) LOGPSIZE, (char *) &logsup, PUT);
 		rc = logend;
 		goto error_out;
 	}
@@ -882,7 +849,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 	 * of volumes which are open if they were modified here.
 	 * i.e. if they were not previously unmounted cleanly.
 	 */
-	for (k = 0; k < MAX_ACTIVE+1; k++) {
+	for (k = 0; k < MAX_ACTIVE + 1; k++) {
 		if (vopen[k].state != VOPEN_OPEN)
 			continue;
 
@@ -918,7 +885,7 @@ int jfs_logredo(caddr_t pathname, int32_t fd, int32_t use_2nd_aggSuper)
 		logsup.state = LOGREDONE;
 		logsup.magic = LOGMAGIC;
 	}
-	ujfs_swap_logsuper_t(&logsup);
+	ujfs_swap_logsuper(&logsup);
 	rc = ujfs_rw_diskblocks(log.fd, (log.xaddr + LOGPNTOB(LOGSUPER_B)),
 				LOGPSIZE, (char *) &logsup, PUT);
 
@@ -1016,7 +983,7 @@ int openVol(int vol)
 		if (!uuid_compare(vopen[vol].uuid, primary_vol.uuid))
 			vopen[vol].fd = primary_vol.fd;
 		else {
-			vopen[vol].fd = open_by_label(vopen[vol].uuid, 0, 0);
+			vopen[vol].fd = open_by_label(vopen[vol].uuid, 0, 0, NULL);
 			if (vopen[vol].fd < 0)
 				return ENOENT;
 		}
@@ -1034,8 +1001,7 @@ int openVol(int vol)
 	/* check magic number and initialize version specific
 	 * values in the vopen struct for this vol.
 	 */
-	if (strncmp(sb.s_magic, JFS_MAGIC, (unsigned) strlen(JFS_MAGIC)))
-	{
+	if (strncmp(sb.s_magic, JFS_MAGIC, (unsigned) strlen(JFS_MAGIC))) {
 		fsck_send_msg(lrdo_FSSUPERBADMAGIC, 0);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADMAGIC);
@@ -1046,8 +1012,7 @@ int openVol(int vol)
 		return (LOGSUPER_BADVERSION);
 	}
 
-	if (log.location & OUTLINELOG &&
-	    (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG))) {
+	if (log.location & OUTLINELOG && (sb.s_flag & (JFS_INLINELOG == JFS_INLINELOG))) {
 		fsck_send_msg(lrdo_FSSUPERBADLOGLOC, 0);
 		vopen[vol].state = VOPEN_CLOSED;
 		return (LOGSUPER_BADLOGLOC);
@@ -1082,8 +1047,7 @@ int openVol(int vol)
 			return JFS_L2BLKSIZE_ERROR;
 		}
 
-		aggsb_numpages =
-			lengthPXD(&sb.s_logpxd) * logsup.bsize / LOGPSIZE;
+		aggsb_numpages = lengthPXD(&sb.s_logpxd) * logsup.bsize / LOGPSIZE;
 		if (logsup.size != aggsb_numpages) {
 			fsck_send_msg(lrdo_LOGSUPBADLOGSZ, 0);
 			return JFS_LOGSIZE_ERROR;
@@ -1130,14 +1094,13 @@ int openVol(int vol)
 	return 0;
 }
 
-
 /*
  * NAME:         updateSuper(vol)
  *
  * FUNCTION:     updates primary aggregate/lv's superblock status and
  *               writes it out.
  */
-int32_t updateSuper(int vol)
+int updateSuper(int vol)
 {				/* device minor number of aggregate/lv */
 	int rc, status;
 	struct superblock sb;
@@ -1162,7 +1125,6 @@ int32_t updateSuper(int vol)
 	return (rc);
 }
 
-
 /*
  * NAME:        rdwrSuper(fd, sb, rwflag)
  *
@@ -1173,11 +1135,9 @@ int32_t updateSuper(int vol)
  *              when both reads failed.
  *              for write, any write failure should be reported.
  */
-int32_t rdwrSuper(int32_t fd,
-		  struct superblock * sb,
-		  int32_t rwflag)
+int rdwrSuper(int32_t fd, struct superblock * sb, int32_t rwflag)
 {
-	int32_t rc;
+	int rc;
 	uint64_t super_offset;
 	union {
 		struct superblock super;
@@ -1201,8 +1161,7 @@ int32_t rdwrSuper(int32_t fd,
 	 */
 	if (rwflag == PB_READ) {
 		rc = ujfs_rw_diskblocks(fd, super_offset,
-					(unsigned) SIZE_OF_SUPER,
-					super.block, GET);
+					(unsigned) SIZE_OF_SUPER, super.block, GET);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
 				fsck_send_msg(lrdo_READFSPRIMSBFAIL, 0);
@@ -1231,8 +1190,7 @@ int32_t rdwrSuper(int32_t fd,
 		 * chkdsk will take care of replicating it.
 		 */
 		rc = ujfs_rw_diskblocks(fd, super_offset,
-					(unsigned) SIZE_OF_SUPER,
-					super.block, PUT);
+					(unsigned) SIZE_OF_SUPER, super.block, PUT);
 		if (rc != 0) {
 			if (!use_2ndary_agg_superblock) {
 				fsck_send_msg(lrdo_WRITEFSPRIMSBFAIL, 0);
@@ -1247,7 +1205,6 @@ int32_t rdwrSuper(int32_t fd,
 	return (0);
 }
 
-
 /*
  * NAME:        bflush()
  *
@@ -1258,7 +1215,8 @@ int32_t rdwrSuper(int32_t fd,
 int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
 	   struct bufpool *buf)
 {				/* pointer to buffer pool page */
-	int32_t rc, fd, vol;
+	int rc;
+	int32_t fd, vol;
 	int32_t nbytes;
 	int64_t blkno;
 
@@ -1279,6 +1237,8 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
 		return (BFLUSH_WRITEERROR);
 	}
 
+	bufhdr[k].modify = 0;
+
 	return (0);
 }
 
@@ -1293,7 +1253,7 @@ int bflush(int32_t k,		/*  The index in bufhdr that describes buf */
  */
 int findLog(int fd)
 {
-	logsuper_t logsup;
+	struct logsuper logsup;
 	struct superblock sb;
 
 	/*
@@ -1307,7 +1267,7 @@ int findLog(int fd)
 	/*
 	 * is the LV a file system ?
 	 */
-	if (memcmp(sb.s_magic, JFS_MAGIC, sizeof(sb.s_magic)) == 0) {
+	if (memcmp(sb.s_magic, JFS_MAGIC, sizeof (sb.s_magic)) == 0) {
 		/*
 		 * does file system contains its in-line log ?
 		 */
@@ -1338,16 +1298,13 @@ int findLog(int fd)
 		if (log_device[0]) {
 			log.fd = open(log_device, LogOpenMode, 0);
 			if (log.fd < 0) {
-				printf("Invalid journal specified (%s)\n", 
-				       log_device);
+				printf("Invalid journal specified (%s)\n", log_device);
 				goto by_uuid;
 			}
 			ujfs_rw_diskblocks(log.fd, LOGPNTOB(LOGSUPER_B),
-					    sizeof(logsuper_t), &logsup,
-					    GET);
-			ujfs_swap_logsuper_t(&logsup);
-			if ((logsup.magic != LOGMAGIC) ||
-			    (uuid_compare(logsup.uuid, sb.s_loguuid))) {
+					   sizeof (struct logsuper), &logsup, GET);
+			ujfs_swap_logsuper(&logsup);
+			if ((logsup.magic != LOGMAGIC) || (uuid_compare(logsup.uuid, sb.s_loguuid))) {
 				close(log.fd);
 				goto by_uuid;
 			}
@@ -1355,8 +1312,8 @@ int findLog(int fd)
 
 			return 0;
 		}
-by_uuid:
-		log.fd = open_by_label(sb.s_loguuid, 0, 1);
+	      by_uuid:
+		log.fd = open_by_label(sb.s_loguuid, 0, 1, NULL);
 
 		if (log.fd >= 0) {
 			log.location |= OUTLINELOG;
@@ -1368,9 +1325,8 @@ by_uuid:
 	/*
 	 * is this an external log?
 	 */
-	ujfs_rw_diskblocks(fd, LOGPNTOB(LOGSUPER_B), sizeof(logsuper_t),
-			   &logsup, GET);
-	ujfs_swap_logsuper_t(&logsup);
+	ujfs_rw_diskblocks(fd, LOGPNTOB(LOGSUPER_B), sizeof (struct logsuper), &logsup, GET);
+	ujfs_swap_logsuper(&logsup);
 	if (logsup.magic != LOGMAGIC) {
 		fsck_send_msg(lrdo_NOTAFSDEV, 0);
 		return NOT_FSDEV_ERROR;
@@ -1484,15 +1440,13 @@ int logError(int type, int logaddr)
 
 	/* mark all open volumes in error
 	 */
-	for (k = 0; k < MAX_ACTIVE+1; k++) {
-		if ((vopen[k].state == VOPEN_OPEN) &&
-		     vopen[k].status != FM_CLEAN)
+	for (k = 0; k < MAX_ACTIVE + 1; k++) {
+		if ((vopen[k].state == VOPEN_OPEN) && vopen[k].status != FM_CLEAN)
 			vopen[k].status = FM_LOGREDO;
 	}
 	return (0);
 }
 
-
 /*
  *	recoverExtendFS()
  *
@@ -1505,12 +1459,12 @@ int logError(int type, int logaddr)
  * at entry, only log type/lv has been validated;
  * for inline log: vopen[0], fs fd = log fd;
  */
-static int32_t recoverExtendFS(int32_t fd)
+static int recoverExtendFS(int32_t fd)
 {
-	int32_t rc;
+	int rc;
 	struct superblock *sbp;
-	dinode_t *dip1, *dip2;
-	dbmap_t *bgcp;
+	struct dinode *dip1, *dip2;
+	struct dbmap *bgcp;
 	xtpage_t *p;
 	int64_t lmchild = 0, xaddr, xoff, barrier, t64, agsize;
 	uint8_t lmxflag;
@@ -1534,7 +1488,7 @@ static int32_t recoverExtendFS(int32_t fd)
 	}
 
 	/* locate the inode in the buffer page */
-	dip1 = (dinode_t *) dip;
+	dip1 = (struct dinode *) dip;
 	dip1 += BMAP_I;
 
 	bp = (char *) &buffer[2];	/* utility buffer */
@@ -1569,13 +1523,12 @@ static int32_t recoverExtendFS(int32_t fd)
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL1, 1);
 		goto errout;
 	}
-	bgcp = (dbmap_t *) bp;
+	bgcp = (struct dbmap *) bp;
 
 	/*
 	 * recover to pre- or post-extendfs state ?:
 	 */
-	if (__le64_to_cpu(bgcp->dn_mapsize) >
-	    (sbp->s_size >> sbp->s_l2bfactor)) {
+	if (__le64_to_cpu(bgcp->dn_mapsize) > (sbp->s_size >> sbp->s_l2bfactor)) {
 		agsize = __le64_to_cpu(bgcp->dn_agsize);
 		goto postx;
 	}
@@ -1595,7 +1548,7 @@ static int32_t recoverExtendFS(int32_t fd)
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL2, 1);
 		goto errout;
 	}
-	dip2 = (dinode_t *) bp;
+	dip2 = (struct dinode *) bp;
 	dip2 += BMAP_I;
 
 	/*
@@ -1604,11 +1557,9 @@ static int32_t recoverExtendFS(int32_t fd)
 	 * Not forgetting to reset di_ixpxd since they are in different
 	 * inode extents.
 	 */
-	memcpy((void *) &temp_pxd, (void *) &(dip1->di_ixpxd),
-	       sizeof(pxd_t));
+	memcpy((void *) &temp_pxd, (void *) &(dip1->di_ixpxd), sizeof (pxd_t));
 	memcpy(dip1, dip2, DISIZE);
-	memcpy((void *) &(dip1->di_ixpxd), (void *) &temp_pxd,
-	       sizeof(pxd_t));
+	memcpy((void *) &(dip1->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
 	if ((rc = ujfs_rw_diskblocks(fd, AITBL_OFF, PSIZE, dip, PUT))) {
 		sprintf(message_parm_0, "0x0%x", AITBL_OFF);
@@ -1648,8 +1599,7 @@ static int32_t recoverExtendFS(int32_t fd)
 			/*
 			 * scan each xad in current xtpage
 			 */
-			for (i = XTENTRYSTART; i < p->header.nextindex;
-			     i++) {
+			for (i = XTENTRYSTART; i < p->header.nextindex; i++) {
 				/* test if extent is of interest */
 				xoff = offsetXAD(&p->xad[i]);
 				if (xoff < barrier)
@@ -1666,19 +1616,11 @@ static int32_t recoverExtendFS(int32_t fd)
 					 * pages
 					 */
 					p->header.next = 0;
-					if ((rc =
-					     ujfs_rw_diskblocks(fd, t64,
-								PSIZE, p,
-								PUT))) {
-						sprintf(message_parm_0,
-							"0x0%llx",
-							(long long) t64);
-						msgprms[0] =
-						    message_parm_0;
+					if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT))) {
+						sprintf(message_parm_0, "0x0%llx", (long long) t64);
+						msgprms[0] = message_parm_0;
 						msgprmidx[0] = 0;
-						fsck_send_msg
-						    (lrdo_EXTFSWRITEBLKFAIL2,
-						     1);
+						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL2, 1);
 						goto errout;
 					}
 				}
@@ -1693,33 +1635,21 @@ static int32_t recoverExtendFS(int32_t fd)
 			if (xaddr) {
 				if (xaddr >= barrier) {
 					p->header.next = 0;
-					if ((rc =
-					     ujfs_rw_diskblocks(fd, t64,
-								PSIZE, p,
-								PUT))) {
-						sprintf(message_parm_0,
-							"0x0%llx",
-							(long long) t64);
-						msgprms[0] =
-						    message_parm_0;
+					if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, p, PUT))) {
+						sprintf(message_parm_0, "0x0%llx", (long long) t64);
+						msgprms[0] = message_parm_0;
 						msgprmidx[0] = 0;
-						fsck_send_msg
-						    (lrdo_EXTFSWRITEBLKFAIL3,
-						     1);
+						fsck_send_msg(lrdo_EXTFSWRITEBLKFAIL3, 1);
 						break;
 					}
 				}
 
 				t64 = xaddr << sbp->s_l2bsize;
-				if ((rc =
-				     ujfs_rw_diskblocks(fd, t64, PSIZE, bp,
-							GET))) {
-					sprintf(message_parm_0, "0x0%llx",
-						(long long) t64);
+				if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
+					sprintf(message_parm_0, "0x0%llx", (long long) t64);
 					msgprms[0] = message_parm_0;
 					msgprmidx[0] = 0;
-					fsck_send_msg
-					    (lrdo_EXTFSREADBLKFAIL3, 1);
+					fsck_send_msg(lrdo_EXTFSREADBLKFAIL3, 1);
 					goto errout;
 				}
 
@@ -1736,11 +1666,8 @@ static int32_t recoverExtendFS(int32_t fd)
 			/* get the leftmost child page  */
 			xaddr = lmchild;
 			t64 = xaddr << sbp->s_l2bsize;
-			if ((rc =
-			     ujfs_rw_diskblocks(fd, t64, PSIZE, bp,
-						GET))) {
-				sprintf(message_parm_0, "0x0%llx",
-					(long long) t64);
+			if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, GET))) {
+				sprintf(message_parm_0, "0x0%llx", (long long) t64);
 				msgprms[0] = message_parm_0;
 				msgprmidx[0] = 0;
 				fsck_send_msg(lrdo_EXTFSREADBLKFAIL4, 1);
@@ -1752,8 +1679,7 @@ static int32_t recoverExtendFS(int32_t fd)
 			lmxflag = p->header.flag;
 			if (lmxflag & BT_INTERNAL) {
 				/* save leftmost child xtpage xaddr */
-				lmchild =
-				    addressXAD(&p->xad[XTENTRYSTART]);
+				lmchild = addressXAD(&p->xad[XTENTRYSTART]);
 			}
 		} else
 			break;
@@ -1790,8 +1716,7 @@ static int32_t recoverExtendFS(int32_t fd)
 	 * overwritten by extendfs() and set superblock clean
 	 */
 	jfs_logform(fd, sbp->s_bsize, sbp->s_l2bsize, sbp->s_flag,
-		    addressPXD(&sbp->s_logpxd), lengthPXD(&sbp->s_logpxd),
-		    NULL);
+		    addressPXD(&sbp->s_logpxd), lengthPXD(&sbp->s_logpxd), NULL, NULL);
 
 	/* update superblock */
 	updateSuper(0);
@@ -1816,7 +1741,7 @@ static int32_t recoverExtendFS(int32_t fd)
 		fsck_send_msg(lrdo_EXTFSREADBLKFAIL5, 1);
 		goto errout;
 	}
-	dip2 = (dinode_t *) bp;
+	dip2 = (struct dinode *) bp;
 	dip2 += BMAP_I;
 
 	/*
@@ -1824,11 +1749,9 @@ static int32_t recoverExtendFS(int32_t fd)
 	 * Not forgetting to reset di_ixpxd since they are in different
 	 * inode extents.
 	 */
-	memcpy((void *) &temp_pxd, (void *) &(dip2->di_ixpxd),
-	       sizeof(pxd_t));
+	memcpy((void *) &temp_pxd, (void *) &(dip2->di_ixpxd), sizeof (pxd_t));
 	memcpy(dip2, dip1, DISIZE);
-	memcpy((void *) &(dip2->di_ixpxd), (void *) &temp_pxd,
-	       sizeof(pxd_t));
+	memcpy((void *) &(dip2->di_ixpxd), (void *) &temp_pxd, sizeof (pxd_t));
 
 	if ((rc = ujfs_rw_diskblocks(fd, t64, PSIZE, bp, PUT))) {
 		sprintf(message_parm_0, "0x0%llx", (long long) t64);
@@ -1889,7 +1812,6 @@ static int32_t recoverExtendFS(int32_t fd)
 	return (EXTENDFS_FAILRECOV);
 }
 
-
 /*
  *
  * NAME:        alloc_dmap_bitrec
@@ -1903,14 +1825,14 @@ static int32_t recoverExtendFS(int32_t fd)
  *		was successfully allocated and there's enough of it left,
  *		this routine will return a piece of it.
  */
-int32_t alloc_dmap_bitrec(dmap_bitmaps_t ** dmap_bitrec)
+int alloc_dmap_bitrec(struct dmap_bitmaps ** dmap_bitrec)
 {
-	int32_t adb_rc = 0;
-	int32_t intermed_rc = 0;
+	int adb_rc = 0;
+	int intermed_rc = 0;
 
 	*dmap_bitrec = NULL;
 
-	intermed_rc = alloc_wrksp((uint32_t) (sizeof(dmap_bitmaps_t)), 0,	/* not meaningful from logredo */
+	intermed_rc = alloc_wrksp((uint32_t) (sizeof (struct dmap_bitmaps)), 0,	/* not meaningful from logredo */
 				  -1,	/* I am logredo */
 				  (void **) dmap_bitrec);
 
@@ -1921,14 +1843,12 @@ int32_t alloc_dmap_bitrec(dmap_bitmaps_t ** dmap_bitrec)
 		/*
 		 * initialize the storage for its new use
 		 */
-		memset((void *) available_stg_addr, 0,
-		       available_stg_bytes);
+		memset((void *) available_stg_addr, 0, available_stg_bytes);
 	}
 
 	return (adb_rc);
 }				/* end alloc_dmap_bitrec() */
 
-
 /*
  *
  * NAME:        alloc_storage
@@ -1939,17 +1859,15 @@ int32_t alloc_dmap_bitrec(dmap_bitmaps_t ** dmap_bitrec)
  *		was successfully allocated and there's enough of it left,
  *		this routine will return a piece of it.
  */
-int32_t alloc_storage(int32_t size_in_bytes,
-		      void **addr_stg_ptr, int32_t * bmap_stg_returned)
+int alloc_storage(int32_t size_in_bytes, void **addr_stg_ptr, int32_t * bmap_stg_returned)
 {
-	int32_t as_rc = 0;
-	int32_t intermed_rc = 0;
+	int as_rc = 0;
+	int intermed_rc = 0;
 
 	*bmap_stg_returned = 0;	/* assume we'll get it the usual way */
 	*addr_stg_ptr = NULL;
 
-	intermed_rc = alloc_wrksp((uint32_t) size_in_bytes, 0, -1,
-				  addr_stg_ptr);
+	intermed_rc = alloc_wrksp((uint32_t) size_in_bytes, 0, -1, addr_stg_ptr);
 
 	if ((intermed_rc != 0) || ((*addr_stg_ptr) == NULL)) {
 		if ((!Insuff_memory_for_maps) && (bmap_stg_addr != NULL)) {
@@ -1963,8 +1881,7 @@ int32_t alloc_storage(int32_t size_in_bytes,
 			/*
 			 * initialize the storage for its new use
 			 */
-			memset((void *) available_stg_addr, 0,
-			       available_stg_bytes);
+			memset((void *) available_stg_addr, 0, available_stg_bytes);
 		}
 		/* end we did allocate storage for the bmap... */
 		if (Insuff_memory_for_maps & (available_stg_bytes != 0)) {
@@ -1980,9 +1897,7 @@ int32_t alloc_storage(int32_t size_in_bytes,
 				/* we can scavenge the memory we need */
 				*addr_stg_ptr = available_stg_addr;
 				available_stg_bytes -= size_in_bytes;
-				available_stg_addr =
-				    (char *) (available_stg_addr +
-					      size_in_bytes);
+				available_stg_addr = (char *) (available_stg_addr + size_in_bytes);
 				*bmap_stg_returned = -1;
 			}
 		} else {
@@ -1993,7 +1908,6 @@ int32_t alloc_storage(int32_t size_in_bytes,
 	return (as_rc);
 }
 
-
 #ifdef  _JFS_WIP
 /*
  *      nfsisloaded()
@@ -2030,7 +1944,7 @@ xdump(char *saddr, int count)
 #define ASCIISTRT  40
 #define HEXEND     36
 	int i, j, k, hexdigit;
-	register int c;
+	int c;
 	char *hexchar;
 	char linebuf[LINESZ + 1];
 	char prevbuf[LINESZ + 1];
@@ -2081,7 +1995,7 @@ xdump(char *saddr, int count)
 	return (0);
 }
 
-int x_scmp(register char *s1, register char *s2)
+int x_scmp(char *s1, char *s2)
 {
 	while ((*s1) && (*s1 == *s2)) {
 		s1++;
@@ -2093,7 +2007,7 @@ int x_scmp(register char *s1, register char *s2)
 		return (0);
 }
 
-void x_scpy(register char *s1, register char *s2)
+void x_scpy(char *s1, char *s2)
 {
 	while ((*s1 = *s2) != '\0') {
 		s1++;
