@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -22,19 +22,18 @@
 #include <unistd.h>
 #include <dirent.h>
 #include <errno.h>
-#include <uuid/uuid.h>
 #include "jfs_endian.h"
 #include "jfs_filsys.h"
 #include "jfs_superblock.h"
 #include "jfs_logmgr.h"
 #include "devices.h"
 
-extern int LogOpenMode;
+int LogOpenMode = O_RDWR;	/* logdump sets this to O_RDONLY */
 
 int open_check_label(char *device, uuid_t uuid, int is_label, int is_log)
 {
 	int fd;
-	logsuper_t logsup;
+	struct logsuper logsup;
 	struct superblock super;
 
 	fd = open(device, LogOpenMode);
@@ -43,8 +42,8 @@ int open_check_label(char *device, uuid_t uuid, int is_label, int is_log)
 
 	if (is_log) {
 		ujfs_rw_diskblocks(fd, LOGSUPER_B << L2LOGPSIZE,
-					sizeof(logsuper_t), &logsup, GET);
-		ujfs_swap_logsuper_t(&logsup);
+				   sizeof (struct logsuper), &logsup, GET);
+		ujfs_swap_logsuper(&logsup);
 		if (logsup.magic == LOGMAGIC) {
 			if (is_label) {
 				if (!strncmp(uuid, logsup.label, 16))
@@ -55,7 +54,7 @@ int open_check_label(char *device, uuid_t uuid, int is_label, int is_log)
 			}
 		}
 	} else {
-		ujfs_rw_diskblocks(fd, SUPER1_OFF, sizeof(super), &super, GET);
+		ujfs_rw_diskblocks(fd, SUPER1_OFF, sizeof (super), &super, GET);
 		ujfs_swap_superblock(&super);
 		if (!memcmp(super.s_magic, JFS_MAGIC, 4)) {
 			if (is_label) {
@@ -87,7 +86,7 @@ int open_check_label(char *device, uuid_t uuid, int is_label, int is_log)
  *
  * NOTE: We may want to cache the uuids already found
  */
-int open_by_label(uuid_t uuid, int is_label, int is_log)
+int open_by_label(uuid_t uuid, int is_label, int is_log, char *dev)
 {
 	char device[100];
 	int fd;
@@ -106,12 +105,14 @@ int open_by_label(uuid_t uuid, int is_label, int is_log)
 		/* evms/volumes should be complete.  If it exists, don't
 		 * search /proc/partitions or /proc/lvm
 		 */
-		while (fgets(line, sizeof(line), part_fd)) {
+		while (fgets(line, sizeof (line), part_fd)) {
 			if (sscanf(line, " %*d %*d %*d %*s %*s %s", device)
 			    != 1)
 				continue;
 			fd = open_check_label(device, uuid, is_label, is_log);
 			if (fd >= 0) {
+				if (dev)
+					strcpy(dev, device);
 				fclose(part_fd);
 				return fd;
 			}
@@ -119,22 +120,23 @@ int open_by_label(uuid_t uuid, int is_label, int is_log)
 		fclose(part_fd);
 
 		printf("Could not locate device by label or uuid!\n");
-	
+
 		return (-ENOENT);
 	}
 
 	/* No evms.  Check /proc/partitions */
 	part_fd = fopen("/proc/partitions", "r");
 	if (part_fd) {
-		while (fgets(line, sizeof(line), part_fd)) {
-			if (sscanf(line, " %*d %*d %d %s", &size,
-				   part_name) != 2)
+		while (fgets(line, sizeof (line), part_fd)) {
+			if (sscanf(line, " %*d %*d %d %s", &size, part_name) != 2)
 				continue;
 			if (size == 1)	/* extended partition */
 				continue;
 			sprintf(device, "/dev/%s", part_name);
 			fd = open_check_label(device, uuid, is_label, is_log);
 			if (fd >= 0) {
+				if (dev)
+					strcpy(dev, device);
 				fclose(part_fd);
 				return fd;
 			}
@@ -148,8 +150,7 @@ int open_by_label(uuid_t uuid, int is_label, int is_log)
 	if (vg_dir) {
 		seekdir(vg_dir, 2);
 		while ((vg_ent = readdir(vg_dir))) {
-			sprintf(lv_dirname, "/proc/lvm/VGs/%s/LVs",
-				vg_ent->d_name);
+			sprintf(lv_dirname, "/proc/lvm/VGs/%s/LVs", vg_ent->d_name);
 			lv_dir = opendir(lv_dirname);
 			if (lv_dir == NULL) {
 				printf("can't open %s\n", lv_dirname);
@@ -157,11 +158,11 @@ int open_by_label(uuid_t uuid, int is_label, int is_log)
 			}
 			seekdir(lv_dir, 2);
 			while ((lv_ent = readdir(lv_dir))) {
-				sprintf(device, "/dev/%s/%s", vg_ent->d_name,
-					lv_ent->d_name);
-				fd = open_check_label(device, uuid, is_label,
-						      is_log);
+				sprintf(device, "/dev/%s/%s", vg_ent->d_name, lv_ent->d_name);
+				fd = open_check_label(device, uuid, is_label, is_log);
 				if (fd >= 0) {
+					if (dev)
+						strcpy(dev, device);
 					closedir(lv_dir);
 					closedir(vg_dir);
 					return fd;
@@ -172,6 +173,6 @@ int open_by_label(uuid_t uuid, int is_label, int is_log)
 		closedir(vg_dir);
 	}
 	printf("Could not locate device by label or uuid!\n");
-	
+
 	return (-ENOENT);
 }
