@@ -1,5 +1,5 @@
 /*
- *   Copyright (c) International Business Machines  Corp., 2000
+ *   Copyright (c) International Business Machines Corp., 2000-2002
  *
  *   This program is free software;  you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,9 +20,14 @@
 
 #include "utilsubs.h"
 
-int32_t ujfs_validate_super(struct superblock *);
-int32_t ujfs_put_superblk(HFILE, struct superblock *, int16_t);
-int32_t ujfs_get_superblk(HFILE, struct superblock *, int32_t);
-int32_t inrange(uint32_t, uint32_t, uint32_t);
+struct superblock;
+struct logsuper;
+
+extern int ujfs_validate_super(struct superblock *);
+extern int ujfs_put_superblk(HFILE, struct superblock *, int16_t);
+extern int ujfs_get_superblk(HFILE, struct superblock *, int32_t);
+extern int ujfs_put_logsuper(HFILE, struct logsuper *);
+extern int ujfs_get_logsuper(HFILE, struct logsuper *);
+extern int inrange(uint32_t, uint32_t, uint32_t);
 
 #endif
